==> haskell-shell-escape-0.2.0-280-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shell-escape.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shell-escape
version:              0.2.0
visibility:           public
id:                   shell-escape-0.2.0-E7amXKNUZ3r9rJH6PwePa2
key:                  shell-escape-0.2.0-E7amXKNUZ3r9rJH6PwePa2
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/shell-escape
synopsis:             Shell escaping library.
description:
    Shell escaping library, offering both Bourne shell and Bash style escaping
    of ByteStrings.

category:             Text
abi:                  edc06f3f0f6db924f574ddde562c029d
exposed:              True
exposed-modules:      Data.ByteString.ShellEscape Text.ShellEscape
hidden-modules:
    Data.ByteString.ShellEscape.Escape
    Data.ByteString.ShellEscape.EscapeVector
    Data.ByteString.ShellEscape.Sh Data.ByteString.ShellEscape.Bash
    Data.ByteString.ShellEscape.Put

import-dirs:          /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shell-escape
hs-libraries:         HSshell-escape-0.2.0-E7amXKNUZ3r9rJH6PwePa2
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    vector-0.13.2.0-9TreTxHfwqF7cSCfMWPj9u

haddock-interfaces:
    /usr/share/doc/haskell-shell-escape/html/shell-escape.haddock

haddock-html:         /usr/share/doc/haskell-shell-escape/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shell-escape-0.2.0-281-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shell-escape.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shell-escape
version:              0.2.0
visibility:           public
id:                   shell-escape-0.2.0-6zgs9ttyg4TK6muMqcRfBT
key:                  shell-escape-0.2.0-6zgs9ttyg4TK6muMqcRfBT
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/shell-escape
synopsis:             Shell escaping library.
description:
    Shell escaping library, offering both Bourne shell and Bash style escaping
    of ByteStrings.

category:             Text
abi:                  57db541ff0e952c85e1a9cb4c6fc6fe6
exposed:              True
exposed-modules:      Data.ByteString.ShellEscape Text.ShellEscape
hidden-modules:
    Data.ByteString.ShellEscape.Escape
    Data.ByteString.ShellEscape.EscapeVector
    Data.ByteString.ShellEscape.Sh Data.ByteString.ShellEscape.Bash
    Data.ByteString.ShellEscape.Put

import-dirs:          /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shell-escape
hs-libraries:         HSshell-escape-0.2.0-6zgs9ttyg4TK6muMqcRfBT
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    vector-0.13.2.0-LerqRcvS8LMBGXOi8GqDsa

haddock-interfaces:
    /usr/share/doc/haskell-shell-escape/html/shell-escape.haddock

haddock-html:         /usr/share/doc/haskell-shell-escape/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
